{% extends "admin/change_form.html" %}
{% load static django_admin_app_sidebar %}

{% block extrahead %}
{{block.super}}
<link rel="stylesheet" type="text/css" href="{% static "django-admin-app-sidebar/css/django-admin-app-sidebar.css" %}" />
{% endblock %}


{% block sidebar %}
<style>


</style>
<div class="django-admin-app-sidebar-wrapper-for-changeform">
    {% portlets_render %}
</div>
{% endblock %}